(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     47496,       1458]
NotebookOptionsPosition[     42766,       1293]
NotebookOutlinePosition[     43277,       1313]
CellTagsIndexPosition[     43234,       1310]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["PwM`Chap04Patterns`", "Section",
 InitializationGroup->True],

Cell[TextData[{
 StyleBox["From",
  FontWeight->"Bold"],
 ": ",
 StyleBox[ButtonBox["Programming with Mathematica: An Introduction",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.cambridge.org/wellin"], None},
  ButtonNote->"http://www.cambridge.org/wellin"],
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}]
}], "Text",
 CellMargins->{{28, 10}, {7, 7}},
 FontSize->14],

Cell[CellGroupData[{

Cell["Metadata", "Subsection"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Name", ":", " ", "PwM`Chap04Patterns`"}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Book", ":", " ", 
    RowBox[{"Programming", " ", "with", " ", 
     RowBox[{"Mathematica", ":", " ", 
      RowBox[{"An", " ", "Introduction"}]}]}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Author", ":", " ", 
    RowBox[{"Paul", " ", "Wellin"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"Summary", ":", " ", 
     RowBox[{
     "This", " ", "package", " ", "contains", " ", "the", " ", "functions", 
      " ", "defined", " ", "in", " ", "Chapter", " ", "4"}]}]}], ",", " ", 
   RowBox[{"Patterns", " ", "and", " ", 
    RowBox[{"rules", "."}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Context", ":", " ", "PwM`Chap04Patterns`"}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Package", " ", 
    RowBox[{"Version", ":", " ", "1.0"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"Copyright", ":", " ", 
     RowBox[{"Copyright", " ", "2012"}]}]}], ",", " ", 
   RowBox[{"Cambridge", " ", "University", " ", "Press"}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"History", ":", " ", 
     RowBox[{
     "Version", " ", "1.0", " ", "by", " ", "Paul", " ", "Wellin"}]}]}], ",", 
   " ", 
   RowBox[{"Dec", " ", "2012"}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"Keywords", ":", " ", "dice"}]}], ",", " ", "arrays", ",", " ", 
   "multiplication", ",", " ", 
   RowBox[{"square", " ", "matrix"}], ",", " ", 
   RowBox[{"area", " ", "of", " ", "triangle"}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Source", ":", " ", 
    RowBox[{"Chap04Patterns", ".", "nb"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Mathematica", " ", 
    RowBox[{"Version", ":", " ", 
     RowBox[{"8.0", ".4"}]}]}]}], " ", "*)"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["BeginPackage", "Subsection"],

Cell[BoxData[
 RowBox[{"Remove", "[", "TriangleArea", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\"\<PwM`Chap04Patterns`\>\"", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage messages for public functions", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Dice", "::", "usage"}], "=", "\"\<Dice[\!\(\*
StyleBox[\"n\", \"TI\"]\)] displays a regular six-sided die with value \!\(\*
StyleBox[\"n\", \"TI\"]\).\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FixArray", "::", "usage"}], "=", "\"\<FixArray[\!\(\*
StyleBox[\"mat\", \"TI\"]\)] replaces any occurrences of the string \\\"NAN\\\
\" with the column mean for each column in which the string appears. \>\""}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MultiplyCount", "::", "usage"}], "=", "\"\<MultiplyCount[\!\(\*
StyleBox[\"expr\", \"TI\"]\)] computes the number of explicit multiplications \
in the arithmetic expression \!\(\*
StyleBox[\"expr\", \"TI\"]\).\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SquareMatrixQ", "::", "usage"}], "=", "\"\<SquareMatrixQ[\!\(\*
StyleBox[\"mat\", \"TI\"]\)] yields true if \!\(\*
StyleBox[\"mat\", \"TI\"]\) is a square matrix.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TriangleArea", "::", "usage"}], "=", "\"\<TriangleArea[\!\(\*
StyleBox[\"vertices\", \"TI\"]\)] computes the area of the triangle specified \
by the three-element list \!\(\*
StyleBox[\"vertices\", \"TI\"]\).\>\""}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Options", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "Dice", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"Color", "\[Rule]", 
     RowBox[{"Darker", "@", "Blue"}]}], "}"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Private context", "Subsection"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function definitions (public and private)", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dice", "[", 
   RowBox[{"n_", ",", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rules", ",", 
      RowBox[{"off", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"OptionValue", "[", "Color", "]"}], ",", 
         RowBox[{"Disk", "[", "]"}]}], "}"}]}], ",", 
      RowBox[{"on", "=", 
       RowBox[{"{", 
        RowBox[{"White", ",", 
         RowBox[{"Disk", "[", "]"}]}], "}"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rules", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "off"}], ",", 
          RowBox[{"2", "\[Rule]", "off"}], ",", 
          RowBox[{"3", "\[Rule]", "off"}], ",", 
          RowBox[{"4", "\[Rule]", "off"}], ",", 
          RowBox[{"5", "\[Rule]", "on"}], ",", 
          RowBox[{"6", "\[Rule]", "off"}], ",", 
          RowBox[{"7", "\[Rule]", "off"}], ",", 
          RowBox[{"8", "\[Rule]", "off"}], ",", 
          RowBox[{"9", "\[Rule]", "off"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "off"}], ",", 
          RowBox[{"2", "\[Rule]", "off"}], ",", 
          RowBox[{"3", "\[Rule]", "on"}], ",", 
          RowBox[{"4", "\[Rule]", "off"}], ",", 
          RowBox[{"5", "\[Rule]", "off"}], ",", 
          RowBox[{"6", "\[Rule]", "off"}], ",", 
          RowBox[{"7", "\[Rule]", "on"}], ",", 
          RowBox[{"8", "\[Rule]", "off"}], ",", 
          RowBox[{"9", "\[Rule]", "off"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "off"}], ",", 
          RowBox[{"2", "\[Rule]", "off"}], ",", 
          RowBox[{"3", "\[Rule]", "on"}], ",", 
          RowBox[{"4", "\[Rule]", "off"}], ",", 
          RowBox[{"5", "\[Rule]", "on"}], ",", 
          RowBox[{"6", "\[Rule]", "off"}], ",", 
          RowBox[{"7", "\[Rule]", "on"}], ",", 
          RowBox[{"8", "\[Rule]", "off"}], ",", 
          RowBox[{"9", "\[Rule]", "off"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "on"}], ",", 
          RowBox[{"2", "\[Rule]", "off"}], ",", 
          RowBox[{"3", "\[Rule]", "on"}], ",", 
          RowBox[{"4", "\[Rule]", "off"}], ",", 
          RowBox[{"5", "\[Rule]", "off"}], ",", 
          RowBox[{"6", "\[Rule]", "off"}], ",", 
          RowBox[{"7", "\[Rule]", "on"}], ",", 
          RowBox[{"8", "\[Rule]", "off"}], ",", 
          RowBox[{"9", "\[Rule]", "on"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "on"}], ",", 
          RowBox[{"2", "\[Rule]", "off"}], ",", 
          RowBox[{"3", "\[Rule]", "on"}], ",", 
          RowBox[{"4", "\[Rule]", "off"}], ",", 
          RowBox[{"5", "\[Rule]", "on"}], ",", 
          RowBox[{"6", "\[Rule]", "off"}], ",", 
          RowBox[{"7", "\[Rule]", "on"}], ",", 
          RowBox[{"8", "\[Rule]", "off"}], ",", 
          RowBox[{"9", "\[Rule]", "on"}]}], "}"}], ",", "\[IndentingNewLine]",
         "\[VeryThinSpace]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1", "\[Rule]", "on"}], ",", 
          RowBox[{"2", "\[Rule]", "off"}], ",", 
          RowBox[{"3", "\[Rule]", "on"}], ",", 
          RowBox[{"4", "\[Rule]", "on"}], ",", 
          RowBox[{"5", "\[Rule]", "off"}], ",", 
          RowBox[{"6", "\[Rule]", "on"}], ",", 
          RowBox[{"7", "\[Rule]", "on"}], ",", 
          RowBox[{"8", "\[Rule]", "off"}], ",", 
          RowBox[{"9", "\[Rule]", "on"}]}], "}"}]}], "\[IndentingNewLine]", 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"GraphicsGrid", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{"Graphics", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Range", "[", "9", "]"}], ",", "3"}], "]"}], "/.", 
          "\[VeryThinSpace]", 
          RowBox[{"rules", "[", 
           RowBox[{"[", "n", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", "2", "}"}]}], "]"}], ",", 
       RowBox[{"Background", "\[Rule]", 
        RowBox[{"First", "[", "off", "]"}]}], ",", 
       RowBox[{"Spacings", "\[Rule]", "10"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "40"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FixArray", "[", "mat_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "fixcolumn", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fixcolumn", "[", "col_", "]"}], ":=", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "col"}], "]"}], "]"}], "/.", 
       RowBox[{"\"\<NAN\>\"", "\[RuleDelayed]", 
        RowBox[{"Mean", "[", 
         RowBox[{"Cases", "[", 
          RowBox[{
           RowBox[{"mat", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "col"}], "]"}], "]"}], ",", 
           RowBox[{"_", "?", "NumberQ"}]}], "]"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Map", "[", 
       RowBox[{"fixcolumn", ",", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", 
          RowBox[{"First", "[", "mat", "]"}], "]"}], "]"}]}], "]"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MultiplyCount", "[", 
   RowBox[{"expr_", "?", "PolynomialQ"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Total", "@", 
    RowBox[{"Cases", "[", 
     RowBox[{
      RowBox[{"{", "expr", "}"}], ",", 
      RowBox[{
       RowBox[{"Power", "[", 
        RowBox[{"_", ",", "exp_"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"exp", "-", "1"}]}], ",", "Infinity"}], "]"}]}], "+", 
   RowBox[{"Total", "@", 
    RowBox[{"Cases", "[", 
     RowBox[{
      RowBox[{"{", "expr", "}"}], ",", 
      RowBox[{"fac_Times", "\[RuleDelayed]", 
       RowBox[{
        RowBox[{"Length", "[", "fac", "]"}], "-", "1"}]}], ",", "Infinity"}], 
     "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SquareMatrixQ", "[", 
   RowBox[{"mat_", "/;", 
    RowBox[{"MatrixQ", "[", "mat", "]"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"Dimensions", "[", "mat", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"Dimensions", "[", "mat", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TriangleArea", "[", 
   RowBox[{"tri", ":", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"_", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_"}], "}"}]}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"PadRight", "[", 
        RowBox[{"#", ",", "3", ",", "1"}], "]"}], "&"}], ",", "tri"}], "]"}], 
    "]"}], "/", "2"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["End private context", "Subsection"],

Cell[BoxData[
 RowBox[{"End", "[", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["EndPackage", "Subsection"],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[CellGroupData[{

Cell["Load package", "Subsection"],

Cell["Quit current session:", "Text"],

Cell[BoxData["Quit"], "Input"],

Cell[TextData[{
 "Load package (do ",
 StyleBox["not",
  FontSlant->"Italic"],
 " say \[OpenCurlyDoubleQuote]Yes\[CloseCurlyDoubleQuote] to evaluate init \
cells dialog)."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "PWM`Chap04Patterns`"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Test usage messages", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Dice"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"Dice[\\!\\(\\*\\nStyleBox[\\\"n\\\", \\\"TI\\\"]\\)] displays \
a regular six-sided die with value \\!\\(\\*\\nStyleBox[\\\"n\\\", \
\\\"TI\\\"]\\).\"\>", "MSG"]], "Print", "PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FixArray"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"FixArray[\\!\\(\\*\\nStyleBox[\\\"mat\\\", \\\"TI\\\"]\\)] \
replaces any occurrences of the string \\\"NAN\\\" with the column mean for \
each column in which the string appears. \"\>", "MSG"]], "Print", \
"PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "MultiplyCount"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"MultiplyCount[\\!\\(\\*\\nStyleBox[\\\"expr\\\", \
\\\"TI\\\"]\\)] computes the number of explicit multiplications in the \
arithmetic expression \\!\\(\\*\\nStyleBox[\\\"expr\\\", \\\"TI\\\"]\\).\"\>",
   "MSG"]], "Print", "PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SquareMatrixQ"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"SquareMatrixQ[\\!\\(\\*\\nStyleBox[\\\"mat\\\", \
\\\"TI\\\"]\\)] yields true if \\!\\(\\*\\nStyleBox[\\\"mat\\\", \
\\\"TI\\\"]\\) is a square matrix.\"\>", "MSG"]], "Print", "PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TriangleArea"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"TriangleArea[\\!\\(\\*\\nStyleBox[\\\"vertices\\\", \
\\\"TI\\\"]\\)] computes the area of the triangle specified by the \
three-element list \\!\\(\\*\\nStyleBox[\\\"vertices\\\", \
\\\"TI\\\"]\\).\"\>", "MSG"]], "Print", "PrintUsage"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise the functions and options", "Subsection"],

Cell[CellGroupData[{

Cell["Dice", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Dice", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "6"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{{
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -740.}, {1110, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -740.}, {740, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -740.}, {370, -1110.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -370.}, {1110, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -370.}, {740, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -370.}, {370, -740.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, 0}, {1110, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, 0}, {740, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {555, -555.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
    ContentSelectable->True,
    ImageSize->40,
    PlotRangePadding->{6, 5}], ",", 
   GraphicsBox[{{{
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -740.}, {1110, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -740.}, {740, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -740.}, {370, -1110.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -370.}, {1110, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -370.}, {740, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -370.}, {370, -740.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, 0}, {1110, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, 0}, {740, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], 
        {555, -925.}, ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
    ContentSelectable->True,
    ImageSize->40,
    PlotRangePadding->{6, 5}], ",", 
   GraphicsBox[{{{
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -740.}, {1110, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -740.}, {740, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -740.}, {370, -1110.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -370.}, {1110, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -370.}, {740, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -370.}, {370, -740.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, 0}, {1110, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, 0}, {740, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {555, -555.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
    ContentSelectable->True,
    ImageSize->40,
    PlotRangePadding->{6, 5}], ",", 
   GraphicsBox[{{{
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -740.}, {1110, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -740.}, {740, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -740.}, {370, -1110.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -370.}, {1110, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -370.}, {740, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -370.}, {370, -740.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, 0}, {1110, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, 0}, {740, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
    ContentSelectable->True,
    ImageSize->40,
    PlotRangePadding->{6, 5}], ",", 
   GraphicsBox[{{{
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -740.}, {1110, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -740.}, {740, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -740.}, {370, -1110.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -370.}, {1110, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -370.}, {740, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -370.}, {370, -740.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, 0}, {1110, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, 0}, {740, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {185, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {555, -555.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {925, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
    ContentSelectable->True,
    ImageSize->40,
    PlotRangePadding->{6, 5}], ",", 
   GraphicsBox[{{{
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -740.}, {1110, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -740.}, {740, -1110.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -740.}, {370, -1110.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, -370.}, {1110, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, -370.}, {740, -740.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, -370.}, {370, -740.}]}}, {
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{740, 0}, {1110, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{370, 0}, {740, -370.}]}, 
       {RGBColor[0, 0, 
         NCache[
          Rational[2, 3], 0.6666666666666666]], 
        RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -185.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -185.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -555.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -555.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -555.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {185, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {RGBColor[0, 0, 
           NCache[
            Rational[2, 3], 0.6666666666666666]], DiskBox[{0, 0}]}], {555, -925.},
         ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
        GraphicsBox[
         {GrayLevel[1], DiskBox[{0, 0}]}], {925, -925.}, 
        ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
    ContentSelectable->True,
    ImageSize->40,
    PlotRangePadding->{6, 5}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dice", "[", 
  RowBox[{"5", ",", 
   RowBox[{"Color", "\[Rule]", "Red"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{{
     {RGBColor[1, 0, 0], RectangleBox[{740, -740.}, {1110, -1110.}]}, 
     {RGBColor[1, 0, 0], RectangleBox[{370, -740.}, {740, -1110.}]}, 
     {RGBColor[1, 0, 0], RectangleBox[{0, -740.}, {370, -1110.}]}}, {
     {RGBColor[1, 0, 0], RectangleBox[{740, -370.}, {1110, -740.}]}, 
     {RGBColor[1, 0, 0], RectangleBox[{370, -370.}, {740, -740.}]}, 
     {RGBColor[1, 0, 0], RectangleBox[{0, -370.}, {370, -740.}]}}, {
     {RGBColor[1, 0, 0], RectangleBox[{740, 0}, {1110, -370.}]}, 
     {RGBColor[1, 0, 0], RectangleBox[{370, 0}, {740, -370.}]}, 
     {RGBColor[1, 0, 0], RectangleBox[{0, 0}, {370, -370.}]}}}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[1], DiskBox[{0, 0}]}], {185, -185.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
      GraphicsBox[
       {RGBColor[1, 0, 0], DiskBox[{0, 0}]}], {555, -185.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
      GraphicsBox[
       {GrayLevel[1], DiskBox[{0, 0}]}], {925, -185.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
      GraphicsBox[
       {RGBColor[1, 0, 0], DiskBox[{0, 0}]}], {185, -555.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
      GraphicsBox[
       {GrayLevel[1], DiskBox[{0, 0}]}], {555, -555.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
      GraphicsBox[
       {RGBColor[1, 0, 0], DiskBox[{0, 0}]}], {925, -555.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[1], DiskBox[{0, 0}]}], {185, -925.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
      GraphicsBox[
       {RGBColor[1, 0, 0], DiskBox[{0, 0}]}], {555, -925.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}], InsetBox[
      GraphicsBox[
       {GrayLevel[1], DiskBox[{0, 0}]}], {925, -925.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.}]}}, {}},
  ContentSelectable->True,
  ImageSize->40,
  PlotRangePadding->{6, 5}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FixArray", "Subsubsection"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"array", "=", 
    TagBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0.9034000000000001`", "\"\<NAN\>\"", "0.7163`", "0.8588`", 
         "0.1228`"},
        {"0.30310000000000004`", "0.5827`", "0.26990000000000003`", 
         "0.8063`", "\"\<NAN\>\""},
        {"0.041800000000000004`", "0.8426`", "\"\<NAN\>\"", 
         "0.8634000000000001`", "0.9682000000000001`"},
        {"0.9163`", "0.8913000000000001`", "0.06620000000000001`", 
         "0.8432000000000001`", "0.054700000000000006`"},
        {"0.7937000000000001`", "0.6905`", "0.9105000000000001`", 
         "0.5589000000000001`", "0.8993`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     Function[BoxForm`e$, 
      MatrixForm[BoxForm`e$]]]}], ";"}],
  NumberMarks->False]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FixArray", "[", "array", "]"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.9034000000000001`", "0.7517750000000001`", "0.7163`", "0.8588`", 
      "0.1228`"},
     {"0.30310000000000004`", "0.5827`", "0.26990000000000003`", "0.8063`", 
      "0.51125`"},
     {"0.041800000000000004`", "0.8426`", "0.490725`", "0.8634000000000001`", 
      "0.9682000000000001`"},
     {"0.9163`", "0.8913000000000001`", "0.06620000000000001`", 
      "0.8432000000000001`", "0.054700000000000006`"},
     {"0.7937000000000001`", "0.6905`", "0.9105000000000001`", 
      "0.5589000000000001`", "0.8993`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["MultiplyCount", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "MultiplyCount"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"MultiplyCount[expr] computes the\[Ellipsis]\"\>", 
  "MSG"]], "Print", "PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MultiplyCount", "[", 
  RowBox[{
   RowBox[{"3", 
    SuperscriptBox["x", "4"]}], "-", 
   RowBox[{"5", "x"}], "+", "2"}], "]"}]], "Input"],

Cell[BoxData["5"], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["SquareMatrixQ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mat", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "mat", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.4095052048321479`", "0.9964868691643753`", "0.2127913440415854`", 
      "0.9029121081866764`"},
     {"0.06775734271174061`", "0.17800565434685622`", "0.2125632640443551`", 
      "0.4304424336723707`"},
     {"0.712729095093247`", "0.880540922351478`", "0.8940131734565542`", 
      "0.981067982945482`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SquareMatrixQ", "[", "mat", "]"}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mat", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "mat", "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.5734388138765454`", "0.6665482580917768`", "0.24429345997422036`", 
      "0.8059132932595943`"},
     {"0.6483189106881719`", "0.5023016682637926`", "0.9395784888303109`", 
      "0.45679361564774723`"},
     {"0.6608887976375835`", "0.7267287791252373`", "0.6464839876727897`", 
      "0.609149452034264`"},
     {"0.9938738156746543`", "0.07532744858153984`", "0.9046688606624953`", 
      "0.4139453383610938`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SquareMatrixQ", "[", "mat", "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["TriangleArea", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TriangleArea", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["y", "1"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["x", "2"], ",", 
      SubscriptBox["y", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["x", "3"], ",", 
      SubscriptBox["y", "3"]}], "}"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["x", "2"]}], " ", 
     SubscriptBox["y", "1"]}], "+", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["y", "1"]}], "+", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["y", "2"]}], "-", 
    RowBox[{
     SubscriptBox["x", "3"], " ", 
     SubscriptBox["y", "2"]}], "-", 
    RowBox[{
     SubscriptBox["x", "1"], " ", 
     SubscriptBox["y", "3"]}], "+", 
    RowBox[{
     SubscriptBox["x", "2"], " ", 
     SubscriptBox["y", "3"]}]}], ")"}]}]], "Output"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{835, 823},
WindowMargins->{{444, Automatic}, {Automatic, 78}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 66, 1, 83, "Section",
 InitializationGroup->True],
Cell[648, 25, 398, 13, 34, "Text"],
Cell[CellGroupData[{
Cell[1071, 42, 30, 0, 42, "Subsection"],
Cell[1104, 44, 129, 3, 33, "Input"],
Cell[1236, 49, 239, 6, 33, "Input"],
Cell[1478, 57, 146, 4, 33, "Input"],
Cell[1627, 63, 359, 9, 53, "Input"],
Cell[1989, 74, 135, 4, 33, "Input"],
Cell[2127, 80, 147, 4, 33, "Input"],
Cell[2277, 86, 241, 7, 33, "Input"],
Cell[2521, 95, 256, 8, 33, "Input"],
Cell[2780, 105, 294, 7, 53, "Input"],
Cell[3077, 114, 152, 4, 33, "Input"],
Cell[3232, 120, 173, 5, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3442, 130, 34, 0, 31, "Subsection"],
Cell[3479, 132, 70, 1, 33, "Input"],
Cell[3552, 135, 91, 1, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3680, 141, 57, 0, 31, "Subsection"],
Cell[3740, 143, 222, 5, 33, "Input"],
Cell[3965, 150, 277, 6, 72, "Input"],
Cell[4245, 158, 281, 6, 72, "Input"],
Cell[4529, 166, 234, 5, 53, "Input"],
Cell[4766, 173, 280, 6, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5083, 184, 29, 0, 31, "Subsection"],
Cell[5115, 186, 198, 6, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5350, 197, 37, 0, 31, "Subsection"],
Cell[5390, 199, 74, 1, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5501, 205, 63, 0, 31, "Subsection"],
Cell[5567, 207, 4534, 110, 281, "Input"],
Cell[10104, 319, 1016, 28, 110, "Input"],
Cell[11123, 349, 683, 20, 72, "Input"],
Cell[11809, 371, 376, 11, 53, "Input"],
Cell[12188, 384, 561, 19, 53, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12786, 408, 41, 0, 31, "Subsection"],
Cell[12830, 410, 51, 1, 63, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12918, 416, 32, 0, 31, "Subsection"],
Cell[12953, 418, 58, 1, 63, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13060, 425, 27, 0, 83, "Section"],
Cell[CellGroupData[{
Cell[13112, 429, 34, 0, 42, "Subsection"],
Cell[13149, 431, 37, 0, 62, "Text"],
Cell[13189, 433, 30, 0, 63, "Input"],
Cell[13222, 435, 183, 6, 62, "Text"],
Cell[13408, 443, 63, 1, 63, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[13508, 449, 41, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[13574, 453, 47, 1, 33, "Input"],
Cell[13624, 456, 215, 3, 95, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[13876, 464, 51, 1, 25, "Input"],
Cell[13930, 467, 249, 4, 135, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[14216, 476, 56, 1, 25, "Input"],
Cell[14275, 479, 266, 4, 95, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[14578, 488, 56, 1, 25, "Input"],
Cell[14637, 491, 218, 3, 95, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[14892, 499, 55, 1, 25, "Input"],
Cell[14950, 502, 265, 4, 95, "Print"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[15264, 512, 56, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[15345, 516, 29, 0, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[15399, 520, 172, 5, 63, "Input"],
Cell[15574, 527, 18068, 470, 135, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[33679, 1002, 116, 3, 63, "Input"],
Cell[33798, 1007, 1931, 40, 132, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[35778, 1053, 33, 0, 21, "Subsubsection"],
Cell[35814, 1055, 1225, 29, 220, "Input"],
Cell[CellGroupData[{
Cell[37064, 1088, 98, 2, 63, "Input"],
Cell[37165, 1092, 1074, 25, 212, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[38288, 1123, 38, 0, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[38351, 1127, 56, 1, 63, "Input"],
Cell[38410, 1130, 113, 2, 95, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[38560, 1137, 163, 5, 78, "Input"],
Cell[38726, 1144, 28, 0, 63, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[38803, 1150, 38, 0, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[38866, 1154, 253, 7, 102, "Input"],
Cell[39122, 1163, 868, 21, 137, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[40027, 1189, 68, 1, 63, "Input"],
Cell[40098, 1192, 32, 0, 63, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[40167, 1197, 253, 7, 102, "Input"],
Cell[40423, 1206, 977, 23, 176, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[41437, 1234, 68, 1, 63, "Input"],
Cell[41508, 1237, 31, 0, 63, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[41588, 1243, 37, 0, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[41650, 1247, 431, 15, 63, "Input"],
Cell[42084, 1264, 630, 23, 102, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
