(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     15389,        542]
NotebookOptionsPosition[     12149,        427]
NotebookOutlinePosition[     12660,        447]
CellTagsIndexPosition[     12617,        444]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["PwM`Chap06Procedural`", "Section",
 InitializationGroup->True],

Cell[TextData[{
 StyleBox["From",
  FontWeight->"Bold"],
 ": ",
 StyleBox[ButtonBox["Programming with Mathematica: An Introduction",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.cambridge.org/wellin"], None},
  ButtonNote->"http://www.cambridge.org/wellin"],
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}]
}], "Text",
 CellMargins->{{28, 10}, {7, 7}},
 FontSize->14],

Cell[CellGroupData[{

Cell["Metadata", "Subsection"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Name", ":", " ", "PwM`Chap06Procedural`"}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Book", ":", " ", 
    RowBox[{"Programming", " ", "with", " ", 
     RowBox[{"Mathematica", ":", " ", 
      RowBox[{"An", " ", "Introduction"}]}]}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Author", ":", " ", 
    RowBox[{"Paul", " ", "Wellin"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"Summary", ":", " ", 
     RowBox[{
     "This", " ", "package", " ", "contains", " ", "the", " ", "functions", 
      " ", "defined", " ", "in", " ", "Chapter", " ", "6"}]}]}], ",", " ", 
   RowBox[{"Procedural", " ", 
    RowBox[{"programming", "."}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Context", ":", " ", "PwM`Chap06Procedural`"}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Package", " ", 
    RowBox[{"Version", ":", " ", "1.0"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"Copyright", ":", " ", 
     RowBox[{"Copyright", " ", "2012"}]}]}], ",", " ", 
   RowBox[{"Cambridge", " ", "University", " ", "Press"}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"History", ":", " ", 
     RowBox[{
     "Version", " ", "1.0", " ", "by", " ", "Paul", " ", "Wellin"}]}]}], ",", 
   " ", 
   RowBox[{"Dec", " ", "2012"}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{":", 
    RowBox[{"Keywords", ":", " ", 
     RowBox[{"digit", " ", "root"}]}]}], ",", " ", 
   RowBox[{"lucky", " ", "number"}], ",", " ", 
   RowBox[{"upper", " ", "triangular", " ", "matrix"}]}], " ", 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Source", ":", " ", 
    RowBox[{"Chap06Procedural", ".", "nb"}]}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{":", 
   RowBox[{"Mathematica", " ", 
    RowBox[{"Version", ":", " ", 
     RowBox[{"8.0", ".4"}]}]}]}], " ", "*)"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["BeginPackage", "Subsection"],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"DigitRoot", ",", "UpperTriangularMatrix"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\"\<PwM`Chap06Procedural`\>\"", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage messages for public functions", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DigitRoot", "::", "usage"}], "=", "\"\<DigitRoot[\!\(\*
StyleBox[\"n\", \"TI\"]\)] returns the digital root of the integer \!\(\*
StyleBox[\"n\", \"TI\"]\).\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LuckyNumbers", "::", "usage"}], "=", "\"\<LuckyNumber[\!\(\*
StyleBox[\"n\", \"TI\"]\)] returns a list of the lucky numbers less than \!\(\*
StyleBox[\"n\", \"TI\"]\).\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UpperTriangularMatrix", "::", "usage"}], "=", 
   "\"\<UpperTriangularMatrix[\!\(\*
StyleBox[\"n\", \"TI\"]\)] returns a square matrix of size \!\(\*
StyleBox[\"n\", \"TI\"]\) with zeros below the diagonal and ones on and above \
the diagonal.\>\""}], ";"}]], "Input"]
}, Closed]],

Cell["Options", "Subsection"],

Cell[CellGroupData[{

Cell["Private context", "Subsection"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function definitions (public and private)", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DigitRoot", "[", 
   RowBox[{"n_Integer", "?", "Positive"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"n", ",", "9"}], "]"}], "\[Equal]", "0"}], ",", "9", ",", 
    RowBox[{"Mod", "[", 
     RowBox[{"n", ",", "9"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LuckyNumbers", "[", 
   RowBox[{"n_Integer", "?", "Positive"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", 
      RowBox[{"i", "=", "2"}], ",", 
      RowBox[{"ints", "=", 
       RowBox[{"Range", "[", 
        RowBox[{"1", ",", "n", ",", "2"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ints", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "<", 
        RowBox[{"Length", "[", "ints", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"p", "=", 
         RowBox[{"ints", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ints", "=", 
         RowBox[{"Drop", "[", 
          RowBox[{"ints", ",", 
           RowBox[{"p", ";;", 
            RowBox[{"-", "1"}], ";;", "p"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"i", "++"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     "ints"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"UpperTriangularMatrix", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m_", ",", "n_"}], "}"}], ",", 
    RowBox[{"val_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"i", "\[GreaterEqual]", "j"}], ",", "0", ",", "val"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "m"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["End private context", "Subsection"],

Cell[BoxData[
 RowBox[{"End", "[", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["EndPackage", "Subsection"],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[CellGroupData[{

Cell["Load package", "Subsection"],

Cell["Quit current session:", "Text"],

Cell[BoxData["Quit"], "Input"],

Cell[TextData[{
 "Load package (do ",
 StyleBox["not",
  FontSlant->"Italic"],
 " say \[OpenCurlyDoubleQuote]Yes\[CloseCurlyDoubleQuote] to evaluate init \
cells dialog)."
}], "Text"],

Cell[BoxData[
 RowBox[{"<<", "PWM`Chap06Procedural`"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Test usage messages", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DigitRoot"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"DigitRoot[\!\(\*\\nStyleBox[\\\"n\\\", \\\"TI\\\"]\)] returns \
the digital root of the integer \!\(\*\\nStyleBox[\\\"n\\\", \\\"TI\\\"]\).\"\
\>", "MSG"]], "Print", "PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "LuckyNumbers"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"LuckyNumber[\!\(\*\\nStyleBox[\\\"n\\\", \\\"TI\\\"]\)] \
returns a list of the lucky numbers less than \!\(\*\\nStyleBox[\\\"n\\\", \\\
\"TI\\\"]\).\"\>", "MSG"]], "Print", "PrintUsage"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "UpperTriangularMatrix"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"UpperTriangularMatrix[\\!\\(\\*\\nStyleBox[\\\"n\\\", \\\"TI\\\
\"]\\)] returns a square matrix of size \\!\\(\\*\\nStyleBox[\\\"n\\\", \
\\\"TI\\\"]\\) with zeros below the diagonal and ones on and above the \
diagonal.\"\>", "MSG"]], "Print", "PrintUsage"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise the functions and their options", "Subsection"],

Cell[CellGroupData[{

Cell["DigitRoot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DigitRoot", "[", 
  RowBox[{"1000", "!"}], "]"}]], "Input"],

Cell[BoxData["9"], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LuckyNumbers", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LuckyNumbers", "[", "1000", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "7", ",", "9", ",", "13", ",", "15", ",", "21", ",", 
   "25", ",", "31", ",", "33", ",", "37", ",", "43", ",", "49", ",", "51", 
   ",", "63", ",", "67", ",", "69", ",", "73", ",", "75", ",", "79", ",", 
   "87", ",", "93", ",", "99", ",", "105", ",", "111", ",", "115", ",", "127",
    ",", "129", ",", "133", ",", "135", ",", "141", ",", "151", ",", "159", 
   ",", "163", ",", "169", ",", "171", ",", "189", ",", "193", ",", "195", 
   ",", "201", ",", "205", ",", "211", ",", "219", ",", "223", ",", "231", 
   ",", "235", ",", "237", ",", "241", ",", "259", ",", "261", ",", "267", 
   ",", "273", ",", "283", ",", "285", ",", "289", ",", "297", ",", "303", 
   ",", "307", ",", "319", ",", "321", ",", "327", ",", "331", ",", "339", 
   ",", "349", ",", "357", ",", "361", ",", "367", ",", "385", ",", "391", 
   ",", "393", ",", "399", ",", "409", ",", "415", ",", "421", ",", "427", 
   ",", "429", ",", "433", ",", "451", ",", "463", ",", "475", ",", "477", 
   ",", "483", ",", "487", ",", "489", ",", "495", ",", "511", ",", "517", 
   ",", "519", ",", "529", ",", "535", ",", "537", ",", "541", ",", "553", 
   ",", "559", ",", "577", ",", "579", ",", "583", ",", "591", ",", "601", 
   ",", "613", ",", "615", ",", "619", ",", "621", ",", "631", ",", "639", 
   ",", "643", ",", "645", ",", "651", ",", "655", ",", "673", ",", "679", 
   ",", "685", ",", "693", ",", "699", ",", "717", ",", "723", ",", "727", 
   ",", "729", ",", "735", ",", "739", ",", "741", ",", "745", ",", "769", 
   ",", "777", ",", "781", ",", "787", ",", "801", ",", "805", ",", "819", 
   ",", "823", ",", "831", ",", "841", ",", "855", ",", "867", ",", "873", 
   ",", "883", ",", "885", ",", "895", ",", "897", ",", "903", ",", "925", 
   ",", "927", ",", "931", ",", "933", ",", "937", ",", "957", ",", "961", 
   ",", "975", ",", "979", ",", "981", ",", "991", ",", "993", ",", "997"}], 
  "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["UpperTriangularMatrix", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"UpperTriangularMatrix", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "5"}], "}"}], ",", "\[Alpha]"}], "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "\[Alpha]", "\[Alpha]", "\[Alpha]", "\[Alpha]"},
     {"0", "0", "\[Alpha]", "\[Alpha]", "\[Alpha]"},
     {"0", "0", "0", "\[Alpha]", "\[Alpha]"},
     {"0", "0", "0", "0", "\[Alpha]"},
     {"0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{740, 867},
WindowMargins->{{554, Automatic}, {Automatic, 43}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 68, 1, 83, "Section",
 InitializationGroup->True],
Cell[650, 25, 398, 13, 34, "Text"],
Cell[CellGroupData[{
Cell[1073, 42, 30, 0, 42, "Subsection"],
Cell[1106, 44, 134, 4, 33, "Input"],
Cell[1243, 50, 239, 6, 33, "Input"],
Cell[1485, 58, 146, 4, 33, "Input"],
Cell[1634, 64, 355, 9, 72, "Input"],
Cell[1992, 75, 137, 4, 33, "Input"],
Cell[2132, 81, 147, 4, 33, "Input"],
Cell[2282, 87, 241, 7, 53, "Input"],
Cell[2526, 96, 256, 8, 33, "Input"],
Cell[2785, 106, 281, 8, 53, "Input"],
Cell[3069, 116, 154, 4, 33, "Input"],
Cell[3226, 122, 173, 5, 33, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3436, 132, 34, 0, 31, "Subsection"],
Cell[3473, 134, 110, 2, 41, "Input"],
Cell[3586, 138, 93, 1, 41, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3716, 144, 57, 0, 31, "Subsection"],
Cell[3776, 146, 228, 5, 53, "Input"],
Cell[4007, 153, 239, 5, 72, "Input"],
Cell[4249, 160, 315, 7, 91, "Input"]
}, Closed]],
Cell[4579, 170, 29, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[4633, 174, 37, 0, 31, "Subsection"],
Cell[4673, 176, 74, 1, 78, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4784, 182, 63, 0, 31, "Subsection"],
Cell[4850, 184, 338, 10, 41, "Input"],
Cell[5191, 196, 1078, 31, 185, "Input"],
Cell[6272, 229, 482, 16, 66, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6791, 250, 41, 0, 31, "Subsection"],
Cell[6835, 252, 51, 1, 78, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6923, 258, 32, 0, 31, "Subsection"],
Cell[6958, 260, 58, 1, 78, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7065, 267, 27, 0, 83, "Section"],
Cell[CellGroupData[{
Cell[7117, 271, 34, 0, 42, "Subsection"],
Cell[7154, 273, 37, 0, 77, "Text"],
Cell[7194, 275, 30, 0, 78, "Input"],
Cell[7227, 277, 183, 6, 77, "Text"],
Cell[7413, 285, 65, 1, 78, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[7515, 291, 41, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[7581, 295, 52, 1, 51, "Input"],
Cell[7636, 298, 208, 3, 118, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[7881, 306, 55, 1, 38, "Input"],
Cell[7939, 309, 216, 3, 118, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[8192, 317, 64, 1, 38, "Input"],
Cell[8259, 320, 287, 4, 168, "Print"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[8595, 330, 62, 0, 31, "Subsection"],
Cell[CellGroupData[{
Cell[8682, 334, 34, 0, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[8741, 338, 83, 2, 78, "Input"],
Cell[8827, 342, 28, 0, 78, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[8904, 348, 37, 0, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[8966, 352, 68, 1, 78, "Input"],
Cell[9037, 355, 1964, 28, 590, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[11050, 389, 46, 0, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[11121, 393, 192, 6, 78, "Input"],
Cell[11316, 401, 781, 20, 265, "Output"]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
